package common

/*
 * This file is part of Autogits.
 *
 * Copyright © 2024 SUSE LLC
 *
 * Autogits is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 2 of the License, or (at your option) any later
 * version.
 *
 * Autogits is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * Foobar. If not, see <https://www.gnu.org/licenses/>.
 */

import (
	"os"
	"strings"
	"testing"
)

func TestPushRequestParsing(t *testing.T) {
	t.Run("parsing repo creation message", func(t *testing.T) {
		var h RequestHandler

		h.StdLogger, h.ErrLogger = CreateStdoutLogger(os.Stdout, os.Stderr)
		json, err := h.parsePushRequest(strings.NewReader(examplePushJSON))
		if err != nil {
			t.Fatalf("failed to parser push request: %v", err)
		}

		if json.Total_Commits < 1 || json.Total_Commits != len(json.Commits) {
			t.Fatalf("push without commits? '%#v'", json)
		}

		if json.Repository.Full_Name != "autogits/_ObsPrj" ||
			json.Repository.Parent != nil ||
			len(json.Repository.Ssh_Url) < 10 ||
			json.Repository.Default_Branch != "main" ||
			json.Repository.Object_Format_Name != "sha256" {

			t.Fatalf("invalid repository parse: %#v", json.Repository)
		}
	})
}
